powered by
Computes the weighted standard deviation of a numeric vector.
weighted.std(x, w, na.rm = TRUE)
Scalar containing the standard deviation
(numeric vector) Variable of interest for which to compute the standard deviation.
(numeric vector) Vector with the weights.
(bool) if TRUE: Excludes missing values before computing the standard deviation
data(df_talis18) weighted.std(df_talis18$tt3g06d1, df_talis18$tt3g06e1)
Run the code above in your browser using DataLab